import * as i0 from '@angular/core';
import { Injectable, EventEmitter, forwardRef, Component, HostListener, Input, Output, NgModule, NO_ERRORS_SCHEMA } from '@angular/core';
import { Subject } from 'rxjs';
import * as i3 from '@angular/forms';
import { NG_VALUE_ACCESSOR, FormsModule } from '@angular/forms';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';

class NgxSuperSelectService {
    constructor() {
        this.registeredSelectBoxIds = [];
        this.popupOpened$ = new Subject();
    }
    register(id) {
        if (this.registeredSelectBoxIds.findIndex(x => x === id) < 0) {
            this.registeredSelectBoxIds.push(id);
        }
    }
    onOpenedSelectPopup(id) {
        this.popupOpened$.next(id);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.0", ngImport: i0, type: NgxSuperSelectService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.0", ngImport: i0, type: NgxSuperSelectService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.0", ngImport: i0, type: NgxSuperSelectService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class NgxSuperSelectOptions {
    constructor() {
        this.actionsEnabled = true;
        this.searchEnabled = true;
        this.placeholder = '';
        this.displayExpr = '';
        this.valueExpr = '';
        this.enableDarkMode = false;
        this.selectionMode = 'multiple';
        this.enableChips = true;
        /**
         * this value will be used when there is no item selected in single selection mode
         */
        this.singleSelectionModeDefaultValue = undefined;
    }
}
const NgxSuperSelectOptionsDefaults = {
    actionsEnabled: true,
    displayExpr: '',
    valueExpr: '',
    placeholder: 'Select',
    searchEnabled: true,
    enableDarkMode: false,
    selectionMode: 'multiple',
    singleSelectionModeDefaultValue: undefined,
    enableChips: true
};

class NgxSuperSelectComponent {
    writeValue(obj) {
        if (Array.isArray(obj) && this.options.selectionMode === 'multiple') {
            this.selectedItemValues = obj;
        }
        else if (this.options.selectionMode === 'single' && obj !== this.options.singleSelectionModeDefaultValue) {
            this.selectedItemValues = [obj];
        }
    }
    registerOnChange(fn) {
        this._onChange = fn;
    }
    registerOnTouched(fn) {
        this._onTouch = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    //#endregion ControlValueAccessor
    onDocumentClicked() {
        this.isOpen = false;
    }
    set options(value) {
        this._options = { ...NgxSuperSelectOptionsDefaults, ...value };
    }
    ;
    get options() {
        return this._options;
    }
    constructor(ngxSuperSelectService) {
        this.ngxSuperSelectService = ngxSuperSelectService;
        this.disabled = false;
        this._options = NgxSuperSelectOptionsDefaults;
        this.selectionChanged = new EventEmitter();
        /**
         * The state of the popup
         */
        this.isOpen = false;
        /**
         * the current searched phrase
         */
        this.searchText = '';
        /**
         * unique id of this instance
         */
        this.selectId = '';
        this.registerSelect();
    }
    /**
     * register this instance for a central control over all instances
     */
    registerSelect() {
        this.selectId = new Date().getTime().toString() + '_' + Math.random();
        this.ngxSuperSelectService.register(this.selectId);
        this.ngxSuperSelectService.popupOpened$.subscribe(id => {
            if (id !== this.selectId) {
                this.isOpen = false;
            }
        });
    }
    onBoxClicked(e) {
        if (!this.disabled) {
            this.isOpen = !this.isOpen;
            if (this.isOpen)
                this.ngxSuperSelectService.onOpenedSelectPopup(this.selectId);
        }
        e.stopPropagation();
        e.preventDefault();
        this.searchText = '';
    }
    onItemClicked(e, item) {
        if (!this.isItemDisabled(item)) {
            const value = this.getValue(item);
            if (this.options.selectionMode === 'multiple') {
                const selectedItemValues = this.selectedItemValues || [];
                if (!Array.isArray(selectedItemValues))
                    return;
                const index = selectedItemValues.findIndex(x => x === value);
                if (index < 0) {
                    const item = [...selectedItemValues];
                    item.push(value);
                    this.selectedItemValues = item;
                }
                else {
                    const item = [...selectedItemValues];
                    item.splice(index, 1);
                    this.selectedItemValues = item;
                }
            }
            else {
                this.selectedItemValues = [value];
            }
        }
        this.handleActionButtonEvent(e);
    }
    onSelectAllClicked(e) {
        const dataSource = this.dataSource;
        if (!Array.isArray(dataSource))
            return;
        this.selectedItemValues = dataSource
            .filter(x => !this.isItemDisabled(x) || this.isItemSelected(x))
            .map(x => this.getValue(x));
        this.handleActionButtonEvent(e);
    }
    onInvertSelectionClicked(e) {
        const dataSource = this.dataSource;
        if (!Array.isArray(dataSource))
            return;
        this.selectedItemValues = dataSource
            .filter(x => {
            if (this.isItemDisabled(x))
                return this.isItemSelected(x);
            return !this.isItemSelected(x);
        })
            .map(x => this.getValue(x));
        this.handleActionButtonEvent(e);
    }
    onClearClicked(e) {
        const dataSource = this.dataSource;
        if (!Array.isArray(dataSource))
            return;
        this.selectedItemValues = dataSource
            .filter(x => this.isItemDisabled(x) && this.isItemSelected(x))
            .map(x => this.getValue(x));
        this.handleActionButtonEvent(e);
    }
    handleActionButtonEvent(e) {
        e.stopPropagation();
        e.preventDefault();
        if (this._onTouch) {
            this._onTouch();
        }
        if (this.options.selectionMode === 'multiple') {
            if (this._onChange) {
                this._onChange(this.selectedItemValues);
            }
            this.selectionChanged.emit(this.selectedItemValues);
        }
        else {
            const value = this.selectedItemValues.length > 0 ? this.selectedItemValues[0] : this.options.singleSelectionModeDefaultValue;
            if (this._onChange) {
                this._onChange(value);
            }
            this.selectionChanged.emit(value);
        }
    }
    onPopupClicked(e) {
        e.stopPropagation();
        e.preventDefault();
    }
    isItemSelected(item) {
        const selectedItemValues = this.selectedItemValues;
        if (!Array.isArray(selectedItemValues))
            return;
        return selectedItemValues.findIndex(x => x === this.getValue(item)) >= 0;
    }
    isItemDisabled(item) {
        const disabledItemValues = this.disabledItemValues;
        if (!Array.isArray(disabledItemValues))
            return;
        return disabledItemValues.findIndex(x => x === this.getValue(item)) >= 0;
    }
    getFilteredItems() {
        const dataSource = this.dataSource;
        if (!Array.isArray(dataSource))
            return [];
        const val = this.searchText.trim().toLocaleLowerCase();
        if (val === '') {
            return dataSource;
        }
        else {
            return dataSource.filter(x => this.getName(x).toLocaleLowerCase().indexOf(val) >= 0);
        }
    }
    getNameForValue(obj) {
        if (this.options.displayExpr?.trim() === '') {
            return obj + '';
        }
        const dataSource = this.dataSource;
        if (!Array.isArray(dataSource))
            return '';
        const index = dataSource.findIndex(x => this.getValue(x) === obj);
        if (index < 0) {
            return obj + '';
        }
        const value = this.dataSource[index][this.options.displayExpr];
        if (value !== undefined)
            return value + '';
        return obj + '';
    }
    getName(obj) {
        if (this.options.displayExpr?.trim() === '') {
            return obj + '';
        }
        const value = obj[this.options.displayExpr];
        if (value !== undefined)
            return value + '';
        return obj + '';
    }
    getValue(obj) {
        if (this.options.valueExpr?.trim() === '') {
            return obj;
        }
        const value = obj[this.options.valueExpr];
        if (value !== undefined)
            return value;
        return obj;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.0", ngImport: i0, type: NgxSuperSelectComponent, deps: [{ token: NgxSuperSelectService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.0", type: NgxSuperSelectComponent, selector: "ngx-super-select", inputs: { dataSource: "dataSource", disabled: "disabled", options: "options", selectedItemValues: "selectedItemValues", disabledItemValues: "disabledItemValues" }, outputs: { selectionChanged: "selectionChanged" }, host: { listeners: { "document:click": "onDocumentClicked()" } }, providers: [{ provide: NG_VALUE_ACCESSOR, useExisting: forwardRef(() => NgxSuperSelectComponent), multi: true }], ngImport: i0, template: "<div class=\"select-box\"\n     [class.open]=\"isOpen\"\n     [class.disabled]=\"disabled\"\n     [class.dark]=\"options.enableDarkMode\"\n     (click)=\"onBoxClicked($event)\">\n\n    <span>{{ options.placeholder }}</span>\n\n    <div *ngIf=\"selectedItemValues && options.enableChips\"\n         class=\"select-selected-items\">\n        <span *ngFor=\"let item of selectedItemValues\">{{ getNameForValue(item) }}</span>\n    </div>\n\n    <span *ngIf=\"selectedItemValues && selectedItemValues.length > 0 && options.selectionMode === 'multiple'\"\n          class=\"selection-counter\">{{ selectedItemValues.length }}</span>\n\n    <div class=\"select-popup\"\n         [class.open]=\"isOpen\"\n         (click)=\"onPopupClicked($event)\">\n\n        <div class=\"select-popup-control-panel\">\n            <div *ngIf=\"options.actionsEnabled\"\n                 class=\"actions\">\n                <button *ngIf=\"options.selectionMode === 'multiple'\"\n                        class=\"btn btn-outline-primary\"\n                        (click)=\"onSelectAllClicked($event)\">\n                    All\n                </button>\n                <button *ngIf=\"options.selectionMode === 'multiple'\"\n                        class=\"btn btn-outline-primary\"\n                        (click)=\"onInvertSelectionClicked($event)\">\n                    Invert\n                </button>\n                <button class=\"btn btn-outline-danger\"\n                        (click)=\"onClearClicked($event)\">\n                    Clear\n                </button>\n            </div>\n\n            <hr *ngIf=\"options.actionsEnabled\">\n\n            <input *ngIf=\"options.searchEnabled\"\n                   type=\"text\"\n                   id=\"searchBox\"\n                   placeholder=\"search\"\n                   [(ngModel)]=\"searchText\"\n                   autocomplete=\"off\">\n\n            <hr *ngIf=\"options.searchEnabled\">\n        </div>\n\n        <div class=\"select-popup-options\">\n            <div *ngFor=\"let item of getFilteredItems()\"\n                 class=\"select-option\"\n                 [class.selected]=\"isItemSelected(item)\"\n                 [class.disabled]=\"isItemDisabled(item)\"\n                 (click)=\"onItemClicked($event, item)\">\n                {{ getName(item) }}\n            </div>\n        </div>\n    </div>\n</div>", styles: ["*{--text-color-dark: #fff;--text-color-light: #000000;--shadow-color-dark: #383838;--shadow-color-light: #d7d7d7;--btn-primary-color-light: rgb(0, 115, 255);--btn-primary-color-dark: rgb(255, 213, 51);--text-secondary-color-dark: #dfdfdf;--text-secondary-color-light: #4d4d4d;--text-disabled-color-dark: #8c8c8c;--text-disabled-color-light: #8c8c8c;--border-color-dark: #505050;--border-color-light: #bebebe;--bg-color-dark: #222222;--bg-color-light: #fff;--bg-secondary-color-dark: #3b3b3b;--bg-secondary-color-light: #ececec;--selection-bg-color-dark: #2c2c2c75;--selection-bg-color-light: #f3f3f3;--selection-bg-hover-color-dark: #3d3d3d;--selection-bg-hover-color-light: #f0f0f0;--selection-indicator-color-dark: #bbbbbb;--selection-indicator-color-light: #858585;--selection-disabled-indicator-color-dark: #6e6e6e;--selection-disabled-indicator-color-light: #bebebe}*{box-sizing:border-box}.select-box{cursor:pointer;height:40px;position:relative;display:grid;grid-template-columns:auto 1fr auto;align-items:center;padding-left:.5rem;padding-right:.2rem;transition-duration:.2s;border-radius:4px;border:1px solid var(--border-color-light);background-color:var(--bg-color-light)}.select-box>span{-webkit-user-select:none;user-select:none;color:var(--text-secondary-color-light)}.select-box.open{min-width:300px}.select-box.disabled{cursor:not-allowed}.select-box.disabled>span{color:var(--text-disabled-color-light)}.select-box .select-selected-items{grid-column:2;display:flex;justify-content:flex-start;align-items:center;gap:4px;margin:0 8px;overflow-x:hidden}.select-box .select-selected-items span{border-radius:4px;padding:4px;color:var(--text-color-light);background-color:var(--bg-secondary-color-light)}.select-box .selection-counter{grid-column:3;margin:0 8px;color:red}.select-popup{position:absolute;display:none;padding:.5rem 0;overflow:hidden;border-radius:4px;box-shadow:0 0 2px 2px var(--shadow-color-light);background-color:var(--bg-color-light);color:var(--text-color-light)}.select-popup hr{margin:.5rem}.select-popup.open{display:grid;grid-template-rows:auto 1fr;width:100%;max-height:400px;z-index:1000;position:absolute;top:100%;left:0}.select-popup .select-popup-control-panel{width:100%}.select-popup .select-popup-control-panel input[type=text]{width:calc(100% - 8px);margin:0 4px;padding:.25rem .5rem;font-size:.875rem;border-radius:4px;border:1px solid #dee2e6;font-weight:400;line-height:1.5;color:var(--text-color-light);background-color:var(--bg-secondary-color-light);border-color:var(--border-color-light)}.select-popup .select-popup-options{width:100%;grid-row:2;overflow-y:auto}.actions{display:flex;justify-content:space-evenly;align-items:center;gap:4px;width:100%}.select-option{-webkit-user-select:none;user-select:none;padding:1rem;width:100%;font-weight:500;font-size:1.2rem;cursor:pointer}.select-option.selected{position:relative;background-color:var(--selection-bg-color-light)}.select-option.selected:before{content:\" \";position:absolute;left:2px;top:10%;display:inline-block;width:4px;height:80%;background-color:var(--selection-indicator-color-light)}.select-option.disabled{cursor:not-allowed;color:var(--text-disabled-color-light)}.select-option.disabled:before{background-color:var(--selection-disabled-indicator-color-light)}.select-option:hover:not(.disabled){background-color:var(--selection-bg-hover-color-light)}.btn{padding:4px;border:none;cursor:pointer;border-radius:4px;background:transparent}.btn.btn-outline-primary{color:var(--btn-primary-color-light);border:1px solid var(--btn-primary-color-light)}.btn.btn-outline-danger{color:#fe3b3b;border:1px solid rgb(254,59,59)}.dark.select-box{border:1px solid var(--border-color-dark);background-color:var(--bg-color-dark)}.dark.select-box>span{color:var(--text-secondary-color-dark)}.dark.select-box .selection-counter{color:red}.dark.select-box.disabled>span{color:var(--text-disabled-color-dark)}.dark.select-box .select-selected-items span{color:var(--text-color-dark);background-color:var(--bg-secondary-color-dark)}.dark.select-box .select-popup{background-color:var(--bg-color-dark);box-shadow:0 0 2px 2px var(--shadow-color-dark);color:var(--text-color-dark)}.dark.select-box .select-popup .select-popup-control-panel input[type=text]{color:var(--text-color-dark);background-color:var(--bg-secondary-color-dark);border-color:var(--border-color-dark)}.dark.select-box .select-option.selected{background-color:var(--selection-bg-color-dark)}.dark.select-box .select-option.selected:before{background-color:var(--selection-indicator-color-dark)}.dark.select-box .select-option.disabled{color:var(--text-disabled-color-dark)}.dark.select-box .select-option.disabled:before{background-color:var(--selection-disabled-indicator-color-dark)}.dark.select-box .select-option:hover:not(.disabled){background-color:var(--selection-bg-hover-color-dark)}.dark .btn.btn-outline-primary{color:var(--btn-primary-color-dark);border:1px solid var(--btn-primary-color-dark)}\n"], dependencies: [{ kind: "directive", type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i3.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i3.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.0", ngImport: i0, type: NgxSuperSelectComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-super-select', providers: [{ provide: NG_VALUE_ACCESSOR, useExisting: forwardRef(() => NgxSuperSelectComponent), multi: true }], template: "<div class=\"select-box\"\n     [class.open]=\"isOpen\"\n     [class.disabled]=\"disabled\"\n     [class.dark]=\"options.enableDarkMode\"\n     (click)=\"onBoxClicked($event)\">\n\n    <span>{{ options.placeholder }}</span>\n\n    <div *ngIf=\"selectedItemValues && options.enableChips\"\n         class=\"select-selected-items\">\n        <span *ngFor=\"let item of selectedItemValues\">{{ getNameForValue(item) }}</span>\n    </div>\n\n    <span *ngIf=\"selectedItemValues && selectedItemValues.length > 0 && options.selectionMode === 'multiple'\"\n          class=\"selection-counter\">{{ selectedItemValues.length }}</span>\n\n    <div class=\"select-popup\"\n         [class.open]=\"isOpen\"\n         (click)=\"onPopupClicked($event)\">\n\n        <div class=\"select-popup-control-panel\">\n            <div *ngIf=\"options.actionsEnabled\"\n                 class=\"actions\">\n                <button *ngIf=\"options.selectionMode === 'multiple'\"\n                        class=\"btn btn-outline-primary\"\n                        (click)=\"onSelectAllClicked($event)\">\n                    All\n                </button>\n                <button *ngIf=\"options.selectionMode === 'multiple'\"\n                        class=\"btn btn-outline-primary\"\n                        (click)=\"onInvertSelectionClicked($event)\">\n                    Invert\n                </button>\n                <button class=\"btn btn-outline-danger\"\n                        (click)=\"onClearClicked($event)\">\n                    Clear\n                </button>\n            </div>\n\n            <hr *ngIf=\"options.actionsEnabled\">\n\n            <input *ngIf=\"options.searchEnabled\"\n                   type=\"text\"\n                   id=\"searchBox\"\n                   placeholder=\"search\"\n                   [(ngModel)]=\"searchText\"\n                   autocomplete=\"off\">\n\n            <hr *ngIf=\"options.searchEnabled\">\n        </div>\n\n        <div class=\"select-popup-options\">\n            <div *ngFor=\"let item of getFilteredItems()\"\n                 class=\"select-option\"\n                 [class.selected]=\"isItemSelected(item)\"\n                 [class.disabled]=\"isItemDisabled(item)\"\n                 (click)=\"onItemClicked($event, item)\">\n                {{ getName(item) }}\n            </div>\n        </div>\n    </div>\n</div>", styles: ["*{--text-color-dark: #fff;--text-color-light: #000000;--shadow-color-dark: #383838;--shadow-color-light: #d7d7d7;--btn-primary-color-light: rgb(0, 115, 255);--btn-primary-color-dark: rgb(255, 213, 51);--text-secondary-color-dark: #dfdfdf;--text-secondary-color-light: #4d4d4d;--text-disabled-color-dark: #8c8c8c;--text-disabled-color-light: #8c8c8c;--border-color-dark: #505050;--border-color-light: #bebebe;--bg-color-dark: #222222;--bg-color-light: #fff;--bg-secondary-color-dark: #3b3b3b;--bg-secondary-color-light: #ececec;--selection-bg-color-dark: #2c2c2c75;--selection-bg-color-light: #f3f3f3;--selection-bg-hover-color-dark: #3d3d3d;--selection-bg-hover-color-light: #f0f0f0;--selection-indicator-color-dark: #bbbbbb;--selection-indicator-color-light: #858585;--selection-disabled-indicator-color-dark: #6e6e6e;--selection-disabled-indicator-color-light: #bebebe}*{box-sizing:border-box}.select-box{cursor:pointer;height:40px;position:relative;display:grid;grid-template-columns:auto 1fr auto;align-items:center;padding-left:.5rem;padding-right:.2rem;transition-duration:.2s;border-radius:4px;border:1px solid var(--border-color-light);background-color:var(--bg-color-light)}.select-box>span{-webkit-user-select:none;user-select:none;color:var(--text-secondary-color-light)}.select-box.open{min-width:300px}.select-box.disabled{cursor:not-allowed}.select-box.disabled>span{color:var(--text-disabled-color-light)}.select-box .select-selected-items{grid-column:2;display:flex;justify-content:flex-start;align-items:center;gap:4px;margin:0 8px;overflow-x:hidden}.select-box .select-selected-items span{border-radius:4px;padding:4px;color:var(--text-color-light);background-color:var(--bg-secondary-color-light)}.select-box .selection-counter{grid-column:3;margin:0 8px;color:red}.select-popup{position:absolute;display:none;padding:.5rem 0;overflow:hidden;border-radius:4px;box-shadow:0 0 2px 2px var(--shadow-color-light);background-color:var(--bg-color-light);color:var(--text-color-light)}.select-popup hr{margin:.5rem}.select-popup.open{display:grid;grid-template-rows:auto 1fr;width:100%;max-height:400px;z-index:1000;position:absolute;top:100%;left:0}.select-popup .select-popup-control-panel{width:100%}.select-popup .select-popup-control-panel input[type=text]{width:calc(100% - 8px);margin:0 4px;padding:.25rem .5rem;font-size:.875rem;border-radius:4px;border:1px solid #dee2e6;font-weight:400;line-height:1.5;color:var(--text-color-light);background-color:var(--bg-secondary-color-light);border-color:var(--border-color-light)}.select-popup .select-popup-options{width:100%;grid-row:2;overflow-y:auto}.actions{display:flex;justify-content:space-evenly;align-items:center;gap:4px;width:100%}.select-option{-webkit-user-select:none;user-select:none;padding:1rem;width:100%;font-weight:500;font-size:1.2rem;cursor:pointer}.select-option.selected{position:relative;background-color:var(--selection-bg-color-light)}.select-option.selected:before{content:\" \";position:absolute;left:2px;top:10%;display:inline-block;width:4px;height:80%;background-color:var(--selection-indicator-color-light)}.select-option.disabled{cursor:not-allowed;color:var(--text-disabled-color-light)}.select-option.disabled:before{background-color:var(--selection-disabled-indicator-color-light)}.select-option:hover:not(.disabled){background-color:var(--selection-bg-hover-color-light)}.btn{padding:4px;border:none;cursor:pointer;border-radius:4px;background:transparent}.btn.btn-outline-primary{color:var(--btn-primary-color-light);border:1px solid var(--btn-primary-color-light)}.btn.btn-outline-danger{color:#fe3b3b;border:1px solid rgb(254,59,59)}.dark.select-box{border:1px solid var(--border-color-dark);background-color:var(--bg-color-dark)}.dark.select-box>span{color:var(--text-secondary-color-dark)}.dark.select-box .selection-counter{color:red}.dark.select-box.disabled>span{color:var(--text-disabled-color-dark)}.dark.select-box .select-selected-items span{color:var(--text-color-dark);background-color:var(--bg-secondary-color-dark)}.dark.select-box .select-popup{background-color:var(--bg-color-dark);box-shadow:0 0 2px 2px var(--shadow-color-dark);color:var(--text-color-dark)}.dark.select-box .select-popup .select-popup-control-panel input[type=text]{color:var(--text-color-dark);background-color:var(--bg-secondary-color-dark);border-color:var(--border-color-dark)}.dark.select-box .select-option.selected{background-color:var(--selection-bg-color-dark)}.dark.select-box .select-option.selected:before{background-color:var(--selection-indicator-color-dark)}.dark.select-box .select-option.disabled{color:var(--text-disabled-color-dark)}.dark.select-box .select-option.disabled:before{background-color:var(--selection-disabled-indicator-color-dark)}.dark.select-box .select-option:hover:not(.disabled){background-color:var(--selection-bg-hover-color-dark)}.dark .btn.btn-outline-primary{color:var(--btn-primary-color-dark);border:1px solid var(--btn-primary-color-dark)}\n"] }]
        }], ctorParameters: function () { return [{ type: NgxSuperSelectService }]; }, propDecorators: { onDocumentClicked: [{
                type: HostListener,
                args: ['document:click']
            }], dataSource: [{
                type: Input
            }], disabled: [{
                type: Input
            }], options: [{
                type: Input
            }], selectedItemValues: [{
                type: Input
            }], disabledItemValues: [{
                type: Input
            }], selectionChanged: [{
                type: Output
            }] } });

class NgxSuperSelectModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.0", ngImport: i0, type: NgxSuperSelectModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.0", ngImport: i0, type: NgxSuperSelectModule, declarations: [NgxSuperSelectComponent], imports: [CommonModule,
            FormsModule], exports: [NgxSuperSelectComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.0", ngImport: i0, type: NgxSuperSelectModule, imports: [CommonModule,
            FormsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.0", ngImport: i0, type: NgxSuperSelectModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        NgxSuperSelectComponent
                    ],
                    imports: [
                        CommonModule,
                        FormsModule
                    ],
                    exports: [
                        NgxSuperSelectComponent
                    ],
                    schemas: [
                        NO_ERRORS_SCHEMA
                    ]
                }]
        }] });

/*
 * Public API Surface of ngx-super-select
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxSuperSelectComponent, NgxSuperSelectModule, NgxSuperSelectOptions, NgxSuperSelectOptionsDefaults, NgxSuperSelectService };
//# sourceMappingURL=ngx-super-select.mjs.map
